/*  xgridloc.h
 *
 *  Header file for gridloc: A GTK+ application to calculate
 *  Maidenhead grid locators give latitude/longitude and vice versa.
 *  Also to calculate bearing and distance to a second location and
 *  display a Great Circle arc from Home to Remote using xplanet
 */

#ifndef GRIDLOCK_H
#define GRIDLOCK_H 1

#include <math.h>
#include <signal.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <stdio.h>


/* Definitions of some flags */
#define HOME_LOC_ENTERED	0X0001
#define REMT_LOC_ENTERED	0X0002
#define XPLANET_ENABLED		0X0004
#define HOME_LONG_WEST		0x0008
#define HOME_LATD_SOUTH		0x0010
#define REMT_LONG_WEST		0x0020
#define REMT_LATD_SOUTH		0x0040
#define DEFAULT_HOME		0x0080

/*-------------------------------------------------------------------*/

/** Table of constant values **/
#define deg2rad  1.74532925E-2   /* Degrees to Radians */
#define pi       3.1415926535898 /* Pi   */
#define pio2     1.5707963267949 /* Pi/2 */
#define twopi    6.2831853071796 /* 2*Pi */
#define eradius  6.378135E3      /* Earth radius in km */
#define eperim   4.0074973E4     /* Earth perimeter in km */

/*-------------------------------------------------------------------*/

/* Return values */
#define ERROR		1
#define SUCCESS		0

/* Special characters */
#define LF      0x0A /* Line Feed */
#define CR      0x0D /* Carriage Return */
#define HT      0x09 /* Horizontal Tab  */

/* xplanet command and files */
#define XPLANET_CMND "xplanet -window -geometry 1024x640 -projection rectangular -config /usr/share/xplanet/config/xgridloc &"
#define CONFIG_FILE	"/usr/share/xplanet/config/xgridloc"
#define MARKER_FILE	"/usr/share/xplanet/markers/xgridloc"
#define ARC_FILE	"/usr/share/xplanet/arcs/xgridloc"

/*-------------------------------------------------------------------*/

/* Function Prototypes produced by cproto */
/* calculate.c */
void Position_to_Gridloc(double lon, double lat, char *grid_loc);
void Gridloc_to_Position(char *grid_loc, double *lon, double *lat);
void Degrees_to_DMS(double deg, int *ideg, int *imin, int *isec);
void DMS_to_Degrees(int ideg, int imin, int isec, double *deg);
void Bearing_Distance(void);
void Read_Home_Position(void);
void Read_Remote_Position(void);
void Read_Home_Locator(void);
void Read_Remote_Locator(void);
void Default_Home_Position(void);
int Display_Location(double remt_bng, double remt_dst);
gboolean Locator_Valid(GtkEntry *entry);
gboolean Position_Valid(GtkEntry *entry, gpointer user_data);
/* callbacks.c */
void Error_Dialog(char *message);
/* main.c */
int main(int argc, char *argv[]);
gboolean Load_Config(gpointer data);
int Load_Line(char *buff, FILE *pfile, char *messg);
void Cleanup(void);
int isFlagSet(int flag);
int isFlagClear(int flag);
void SetFlag(int flag);
void ClearFlag(int flag);
void ToggleFlag(int flag);
void Usage(void);

/*-------------------------------------------------------------------*/

#endif /* End of xgridloc.h */

